@@ -1,5 +1,5 @@
 /* Libvoikko: Library of Finnish language tools
- * Copyright (C) 2009 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2009 - 2010 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,6 +67,10 @@ list<Analysis *> * MalagaAnalyzer::analyze(const char * word) {
 			parseBasicAttribute(analysis, res, symbols[MS_NUMBER], "NUMBER");
 			parseBasicAttribute(analysis, res, symbols[MS_PERSON], "PERSON");
 			parseBasicAttribute(analysis, res, symbols[MS_MOOD], "MOOD");
+			parseBasicAttribute(analysis, res, symbols[MS_VAPAA_JALKIOSA], "MALAGA_VAPAA_JALKIOSA");
+			parseBasicAttribute(analysis, res, symbols[MS_NEGATIVE], "NEGATIVE");
+			parseBasicAttribute(analysis, res, symbols[MS_POSSIBLE_GEOGRAPHICAL_NAME], "POSSIBLE_GEOGRAPHICAL_NAME");
+			parseBasicAttribute(analysis, res, symbols[MS_REQUIRE_FOLLOWING_VERB], "REQUIRE_FOLLOWING_VERB");
 			parsePerusmuoto(analysis, res);
 			analysisList->push_back(analysis);
 			res = next_analysis_result(&malagaState);
@@ -85,8 +89,18 @@ void MalagaAnalyzer::terminate() {
 }
 
 symbol_t MalagaAnalyzer::findSymbol(const char * name) {
-	value_t symbolValue = parse_malaga_symbol(name, &malagaState);
-	symbol_t symbol = value_to_symbol(symbolValue);
+	value_t symbolValue;
+	try {
+		symbolValue = parse_malaga_symbol(name, &malagaState);
+	} catch (setup::DictionaryException e) {
+		return 0;
+	}
+	symbol_t symbol;
+	try {
+		symbol = value_to_symbol(symbolValue);
+	} catch (setup::DictionaryException e) {
+		symbol = 0;
+	}
 	free(symbolValue);
 	return symbol;
 }
@@ -122,6 +136,18 @@ void MalagaAnalyzer::initSymbols() {
 			case MS_MOOD:
 				symbolName = "tapaluokka";
 				break;
+			case MS_VAPAA_JALKIOSA:
+				symbolName = "vapaa_j\xc3\xa4lkiosa";
+				break;
+			case MS_NEGATIVE:
+				symbolName = "kielto";
+				break;
+			case MS_POSSIBLE_GEOGRAPHICAL_NAME:
+				symbolName = "paikannimen_j\xc3\xa4lkiliite";
+				break;
+			case MS_REQUIRE_FOLLOWING_VERB:
+				symbolName = "vaatii_tapaluokan";
+				break;
 		}
 		symbols[sym] = findSymbol(symbolName);
 	}
@@ -167,11 +193,19 @@ void MalagaAnalyzer::initSymbols() {
 	insertToSymbolMap(symbolMap, "tekij\xc3\xa4_1", L"1");
 	insertToSymbolMap(symbolMap, "tekij\xc3\xa4_2", L"2");
 	insertToSymbolMap(symbolMap, "tekij\xc3\xa4_3", L"3");
+	insertToSymbolMap(symbolMap, "tekij\xc3\xa4_4", L"4");
 	
 	insertToSymbolMap(symbolMap, "tositapa", L"indicative");
 	insertToSymbolMap(symbolMap, "k\xc3\xa4skytapa", L"imperative");
 	insertToSymbolMap(symbolMap, "ehtotapa", L"conditional");
 	insertToSymbolMap(symbolMap, "mahtotapa", L"potential");
+	insertToSymbolMap(symbolMap, "nimitapa_1", L"A-infinitive");
+	insertToSymbolMap(symbolMap, "nimitapa_2", L"E-infinitive");
+	insertToSymbolMap(symbolMap, "nimitapa_3", L"MA-infinitive");
+	
+	insertToSymbolMap(symbolMap, "yes", L"true");
+	insertToSymbolMap(symbolMap, "no", L"false");
+	insertToSymbolMap(symbolMap, "molemmat", L"both");
 }
 
 void MalagaAnalyzer::parseStructure(Analysis * &analysis, value_t &result) const {
@@ -184,11 +218,19 @@ void MalagaAnalyzer::parseStructure(Analysis * &analysis, value_t &result) const
 
 void MalagaAnalyzer::parseBasicAttribute(Analysis * &analysis, value_t &result,
                                          symbol_t symbol, const char * attrName) const {
+	if (!symbol) {
+		return;
+	}
 	value_t value = get_attribute(result, symbol);
 	if (!value) {
 		return;
 	}
-	symbol_t valueSym = value_to_symbol(value);
+	symbol_t valueSym;
+	try {
+		valueSym = value_to_symbol(value);
+	} catch (setup::DictionaryException e) {
+		return;
+	}
 	map<symbol_t, const wchar_t *>::const_iterator mapIterator = symbolMap.find(valueSym);
 	if (mapIterator == symbolMap.end()) {
 		return;
